package models

import (
	"eta/eta_index_lib/utils"
	"fmt"
	"github.com/beego/beego/v2/client/orm"
	"strconv"
	"strings"
	"time"
)

type FuBaoData struct {
	ReturnValue struct {
		Product struct {
			AlikeName    string `json:"alikeName"`
			DiffName     string `json:"diffName"`
			PropValueStr string `json:"propValueStr"`
			Pattern      string `json:"pattern"`
		} `json:"product"`
		Data []struct {
			PriceStr string `json:"priceStr"`
			Uad      string `json:"uad"`
			Datadate string `json:"datadate"`
		} `json:"data"`
	} `json:"returnValue"`
	Code int `json:"code"`
}

// 新增富宝指标数据
func AddEdbDataFromFubao(edbCode string, fubaoData *FuBaoData) (err error) {
	o := orm.NewOrm()
	var isAdd bool
	addSql := ` INSERT INTO edb_data_fubao(edb_info_id,edb_code,data_time,value,create_time,modify_time,data_timestamp) values `
	for _, dataItem := range fubaoData.ReturnValue.Data {
		dataTime, err := time.ParseInLocation(utils.FormatDate, dataItem.Datadate, time.Local)
		if err != nil {
			return err
		}
		eDate := dataTime.Format(utils.FormatDate)
		if err != nil {
			return err
		}
		timestamp := dataTime.UnixNano() / 1e6
		timeStr := fmt.Sprintf("%d", timestamp)
		addSql += GetAddSql("0", edbCode, eDate, timeStr, dataItem.PriceStr)
		isAdd = true
	}
	if isAdd {
		addSql = strings.TrimRight(addSql, ",")
		_, err = o.Raw(addSql).Exec()
		if err != nil {
			fmt.Println("RefreshAllEdbDataByFubao add Err", err.Error())
			return
		}
	}
	return
}

// 刷新路透指标数据
func RefreshEdbDataFromFubao(edbInfoId int, edbCode, startDate string, fubaoData *FuBaoData) (err error) {
	source := utils.DATA_SOURCE_FUBAO
	o := orm.NewOrm()

	// 真实数据的最大日期  ， 插入规则配置的日期
	var realDataMaxDate, edbDataInsertConfigDate time.Time
	var edbDataInsertConfig *EdbDataInsertConfig
	var isFindConfigDateRealData bool //是否找到配置日期的实际数据的值
	{
		edbDataInsertConfig, err = GetEdbDataInsertConfigByEdbId(edbInfoId)
		if err != nil && err.Error() != utils.ErrNoRow() {
			return
		}
		if edbDataInsertConfig != nil {
			edbDataInsertConfigDate = edbDataInsertConfig.Date
		}
	}

	var existCondition string
	var existPars []interface{}

	existCondition += " AND edb_info_id=? "
	existPars = append(existPars, edbInfoId)
	//if startDate != "" {
	//	existCondition += " AND data_time>=? "
	//	existPars = append(existPars, startDate)
	//}

	existList, err := GetEdbDataByCondition(source, existCondition, existPars)
	if err != nil {
		return err
	}
	existMap := make(map[string]*EdbInfoSearchData)
	for _, v := range existList {
		existMap[v.DataTime] = v
	}

	fmt.Println("existMap start")
	fmt.Println(existMap)
	fmt.Println("existMap end")

	edbInfoIdStr := strconv.Itoa(edbInfoId)

	addSql := ` INSERT INTO edb_data_fubao(edb_info_id,edb_code,data_time,value,create_time,modify_time,data_timestamp) values `
	var isAdd bool

	for _, dataItem := range fubaoData.ReturnValue.Data {

		dataTime, err := time.ParseInLocation(utils.FormatDate, dataItem.Datadate, time.Local)
		if err != nil {
			return err
		}

		if findItem, ok := existMap[dataItem.Datadate]; !ok {
			timestamp := dataTime.UnixNano() / 1e6
			timeStr := fmt.Sprintf("%d", timestamp)

			addSql += GetAddSql(edbInfoIdStr, edbCode, dataItem.Datadate, timeStr, dataItem.PriceStr)
			isAdd = true
		} else {
			fmt.Println("update start")
			fmt.Println(findItem.Value)
			fmt.Println(dataItem.PriceStr)
			fmt.Println(utils.SubFloatToString(findItem.Value, 30))
			fmt.Println("update end")

			if findItem != nil && utils.SubFloatToString(findItem.Value, 30) != dataItem.PriceStr {
				err = ModifyEdbDataById(source, findItem.EdbDataId, dataItem.PriceStr)
				if err != nil {
					return err
				}
			}
		}

		// 下面代码主要目的是处理掉手动插入的数据判断
		{
			if realDataMaxDate.IsZero() || dataTime.After(realDataMaxDate) {
				realDataMaxDate = dataTime
			}
			if edbDataInsertConfigDate.IsZero() || dataTime.Equal(edbDataInsertConfigDate) {
				isFindConfigDateRealData = true
			}
		}
	}

	// 处理手工数据补充的配置
	HandleConfigInsertEdbData(realDataMaxDate, edbDataInsertConfig, edbInfoId, source, existMap, isFindConfigDateRealData)

	if isAdd {
		addSql = strings.TrimRight(addSql, ",")
		_, err = o.Raw(addSql).Exec()
		if err != nil {
			fmt.Println("RefreshEdbDataFromFubao Err", err.Error())
			return
		}
	}
	return
}
